Bugfix 334 - Interne Notizen wurden bei gesetzter Lieferanschrift als Notizen auf
authorStephan Köhler <s.koehler@linet-services.de>
Thu, 6 Apr 2006 10:42:47 +0000 (10:42 +0000)
committerStephan Köhler <s.koehler@linet-services.de>
Thu, 6 Apr 2006 10:42:47 +0000 (10:42 +0000)
den Angeboten, Auftraegen und Rechnungen dargestellt

SL/IS.pm

index d4d8c6f..31ded06 100644 (file)
--- a/SL/IS.pm
+++ b/SL/IS.pm
@@ -360,8 +360,8 @@ sub customer_details {
 
   $ref = $sth->fetchrow_hashref(NAME_lc);
 
-  # remove id and taxincluded before copy back
-  delete @$ref{qw(id taxincluded)};
+  # remove notes, id and taxincluded before copy back
+  delete @$ref{qw(id taxincluded notes)};
   map { $form->{$_} = $ref->{$_} } keys %$ref;
 
   $sth->finish;